==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/CascadeOnActivate.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.query;
namespace com.db4o.test {

   public class CascadeOnActivate {
      
      public CascadeOnActivate() : base() {
      }
      public String name;
      public CascadeOnActivate child;
      
      public void configure() {
         Db4o.configure().objectClass(this).cascadeOnActivate(true);
      }
      
      public void store() {
         name = "1";
         child = new CascadeOnActivate();
         child.name = "2";
         child.child = new CascadeOnActivate();
         child.child.name = "3";
         Tester.store(this);
      }
      
      public void test() {
         Query q1 = Tester.query();
         q1.constrain(j4o.lang.Class.getClassForObject(this));
         q1.descend("name").constrain("1");
         ObjectSet os1 = q1.execute();
         CascadeOnActivate coa1 = (CascadeOnActivate)os1.next();
         CascadeOnActivate coa31 = coa1.child.child;
         Tester.ensure(coa31.name.Equals("3"));
         Tester.objectContainer().deactivate(coa1, Int32.MaxValue);
         Tester.ensure(coa31.name == null);
         Tester.objectContainer().activate(coa1, 1);
         Tester.ensure(coa31.name.Equals("3"));
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/CascadeOnActivate.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.query;
namespace com.db4o.test {

   public class CascadeOnActivate {
      
      public CascadeOnActivate() : base() {
      }
      public String name;
      public CascadeOnActivate child;
      
      public void Configure() {
         Db4o.Configure().ObjectClass(this).CascadeOnActivate(true);
      }
      
      public void Store() {
         name = "1";
         child = new CascadeOnActivate();
         child.name = "2";
         child.child = new CascadeOnActivate();
         child.child.name = "3";
         Tester.Store(this);
      }
      
      public void Test() {
         Query q1 = Tester.Query();
         q1.Constrain(j4o.lang.Class.GetClassForObject(this));
         q1.Descend("name").Constrain("1");
         ObjectSet os1 = q1.Execute();
         CascadeOnActivate coa1 = (CascadeOnActivate)os1.Next();
         CascadeOnActivate coa31 = coa1.child.child;
         Tester.Ensure(coa31.name.Equals("3"));
         Tester.ObjectContainer().Deactivate(coa1, Int32.MaxValue);
         Tester.Ensure(coa31.name == null);
         Tester.ObjectContainer().Activate(coa1, 1);
         Tester.Ensure(coa31.name.Equals("3"));
      }
   }
}
